==============================
:code:`Trakt['sync/playback']`
==============================

.. automodule:: trakt.interfaces.sync.playback

  .. autoclass:: SyncPlaybackInterface
    :members: delete, episodes, flags, get, movies, shows
    :undoc-members:
